@@ -1,8 +1,10 @@
 use v5.20;
 use warnings;
-package Log::Dispatchouli::Proxy 3.001;
+package Log::Dispatchouli::Proxy 3.003;
 # ABSTRACT: a simple wrapper around Log::Dispatch
 
+use experimental 'postderef'; # Not dangerous.  Is accepted without changed.
+
 use Log::Fmt ();
 use Params::Util qw(_ARRAY0 _HASH0);
 
@@ -195,7 +197,7 @@ Log::Dispatchouli::Proxy - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 3.001
+version 3.003
 
 =head1 DESCRIPTION
 
@@ -224,13 +226,13 @@ C<log_debug> messages will be redispatched to C<log> (to the 'debug' logging lev
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should work
-on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 AUTHOR
 
@@ -238,7 +240,7 @@ Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Ricardo SIGNES.
+This software is copyright (c) 2023 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
